@@ -178,14 +178,14 @@ def _EmitLineUnformatted(state):
     previous_token = state.next_token.previous_token
     previous_lineno = previous_token.lineno
 
-    if previous_token.is_multiline_string:
+    if previous_token.is_multiline_string or previous_token.is_string:
       previous_lineno += previous_token.value.count('\n')
 
     if previous_token.is_continuation:
       newline = False
     else:
-      newline = (prev_lineno is not None and
-                 state.next_token.lineno > previous_lineno)
+      newline = (
+          prev_lineno is not None and state.next_token.lineno > previous_lineno)
 
     prev_lineno = state.next_token.lineno
     state.AddTokenToState(newline=newline, dry_run=False)
