@@ -24,10 +24,11 @@ from yapf.yapflib import style
 # TODO(morbo): Document the annotations in a centralized place. E.g., the
 # README file.
 UNBREAKABLE = 1000 * 1000
-NAMED_ASSIGN = 8500
+NAMED_ASSIGN = 11000
 DOTTED_NAME = 4000
 VERY_STRONGLY_CONNECTED = 3500
 STRONGLY_CONNECTED = 3000
+CONNECTED = 500
 
 OR_TEST = 1000
 AND_TEST = 1100
@@ -133,6 +134,9 @@ class _SplitPenaltyAssigner(pytree_visitor.PyTreeVisitor):
       if isinstance(child, pytree.Leaf) and child.value == ',':
         _SetUnbreakable(child)
       index += 1
+    for child in node.children:
+      if pytree_utils.NodeName(child) == 'atom':
+        _IncreasePenalty(child, CONNECTED)
 
   def Visit_argument(self, node):  # pylint: disable=invalid-name
     # argument ::= test [comp_for] | test '=' test  # Really [keyword '='] test
@@ -184,12 +188,11 @@ class _SplitPenaltyAssigner(pytree_visitor.PyTreeVisitor):
       _SetSplitPenalty(node.children[1], VERY_STRONGLY_CONNECTED)
     elif len(node.children) == 3:
       name = pytree_utils.NodeName(node.children[1])
-      if name == 'power':
-        if pytree_utils.NodeName(node.children[1].children[0]) != 'atom':
-          # Don't split an argument list with one element if at all possible.
-          _SetStronglyConnected(node.children[1], node.children[2])
-          _SetSplitPenalty(
-              _FirstChildNode(node.children[1]), ONE_ELEMENT_ARGUMENT)
+      if name in {'argument', 'comparison'}:
+        # Don't split an argument list with one element if at all possible.
+        _SetStronglyConnected(node.children[1])
+        _SetSplitPenalty(
+            _FirstChildNode(node.children[1]), ONE_ELEMENT_ARGUMENT)
       elif (pytree_utils.NodeName(node.children[0]) == 'LSQB' and
             len(node.children[1].children) > 2 and
             (name.endswith('_test') or name.endswith('_expr'))):
@@ -210,7 +213,7 @@ class _SplitPenaltyAssigner(pytree_visitor.PyTreeVisitor):
         _SetVeryStronglyConnected(node.children[-1])
       elif name not in {
           'arglist', 'argument', 'term', 'or_test', 'and_test', 'comparison',
-          'atom'
+          'atom', 'power'
       }:
         # Don't split an argument list with one element if at all possible.
         _SetStronglyConnected(node.children[1], node.children[2])
@@ -383,6 +386,18 @@ class _SplitPenaltyAssigner(pytree_visitor.PyTreeVisitor):
     self.DefaultNodeVisit(node)
     _IncreasePenalty(node, ARITH_EXPR)
 
+    index = 1
+    while index < len(node.children) - 1:
+      child = node.children[index]
+      if isinstance(child, pytree.Leaf) and child.value in '+-':
+        next_node = _FirstChildNode(node.children[index + 1])
+        _SetSplitPenalty(
+            next_node,
+            pytree_utils.GetNodeAnnotation(
+                next_node, pytree_utils.Annotation.SPLIT_PENALTY, default=0) -
+            100)
+      index += 1
+
   def Visit_term(self, node):  # pylint: disable=invalid-name
     # term ::= factor (('*'|'@'|'/'|'%'|'//') factor)*
     _IncreasePenalty(node, TERM)
