@@ -79,8 +79,8 @@ class UnwrappedLine(object):
       # because these may use it for their decision.
       token.split_penalty += _SplitPenalty(prev_token, token)
       token.must_break_before = _MustBreakBefore(prev_token, token)
-      token.can_break_before = (token.must_break_before or
-                                _CanBreakBefore(prev_token, token))
+      token.can_break_before = (
+          token.must_break_before or _CanBreakBefore(prev_token, token))
 
       prev_length = token.total_length
       prev_token = token
